@@ -15,7 +15,10 @@ _deleted = 'deleted'
 
 @cache
 def _servers():
-    return cfg_read().get('sql_server', {})
+    res = cfg_read().get('sql_server', {})
+    if isinstance(res, dict):
+        res[None] = res.get('null', None)
+    return res
 
 @cache
 def _schema():
